@@ -6,7 +6,7 @@
 #define XS(name) void name(cv) CV* cv;
 #endif
 
-#if defined(WIN32) && defined(__GNUC__)
+#if 0 /*defined(WIN32) && defined(__GNUC__)*/ /* this bug is gone in mingw32/gcc-2.8.0*/
 #define STRINGIFY_THINGY(x) #x
 #define FORCE_ARG_STRING(x) STRINGIFY_THINGY(x)
 #else
@@ -50,7 +50,7 @@
 #ifdef XS_VERSION
 # define XS_VERSION_BOOTCHECK \
     STMT_START {							\
-        char *xs_version = FORCE_ARG_STRING(XS_VERSION);			\
+        char *xs_version = FORCE_ARG_STRING(XS_VERSION);		\
 	char *vn = "", *module = SvPV(ST(0),na);			\
 	if (items >= 2)	 /* version supplied as bootstrap arg */	\
 	    Sv = ST(1);							\
