@@ -29,6 +29,7 @@
 #    define pthread_mutexattr_default NULL
 #    define pthread_condattr_default NULL
 #    define pthread_addr_t any_t
+#    define PTHREAD_CREATE_JOINABLE (&err)
 #  endif
 #else	/* DJGPP */
 #  ifdef WIN32
@@ -121,6 +122,7 @@
 #  define HAS_UTIME
 #  define HAS_KILL
 #  define HAS_WAIT
+#  define HAS_CHOWN
 /*
  * This provides a layer of functions and macros to ensure extensions will
  * get to use the same RTL functions as the core.
