@@ -426,18 +426,17 @@ gv_fetchpv(char *nambeg, I32 add, I32 sv_type)
 		tmpbuf[len++] = ':';
 		tmpbuf[len] = '\0';
 		gvp = (GV**)hv_fetch(stash,tmpbuf,len,add);
+		gv = gvp ? *gvp : Nullgv;
+		if (gv && gv != (GV*)&sv_undef) {
+		    if (SvTYPE(gv) != SVt_PVGV)
+			gv_init(gv, stash, tmpbuf, len, (add & 2));
+		    else
+			GvMULTI_on(gv);
+		}
 		if (tmpbuf != autobuf)
 		    Safefree(tmpbuf);
-		if (!gvp || *gvp == (GV*)&sv_undef)
+		if (!gv || gv == (GV*)&sv_undef)
 		    return Nullgv;
-		gv = *gvp;
-
-                if (SvTYPE(gv) == SVt_PVGV)
-                    GvMULTI_on(gv);
-                else if (!add)
-                    return Nullgv;
-		else
-		    gv_init(gv, stash, nambeg, namend - nambeg, (add & 2));
 
 		if (!(stash = GvHV(gv)))
 		    stash = GvHV(gv) = newHV();
