@@ -43,10 +43,8 @@
 # "ext.libs" file which is *probably* messing up the order.  Often,
 # you can replace ext.libs with an empty file to fix the problem.
 #
-# If you get a message about "too much defining", as may happen
-# in HPUX < 10, you might have to append a single entry to your
-# ccflags: '-Wp,-H256000'
-# NOTE: This is a single entry (-W takes the argument 'p,-H256000').
+# If you get a message about "too much defining", you might have to
+# add the following to your ccflags: '-Wp,-H256000'
 #--------------------------------------------------------------------
 
 # Turn on the _HPUX_SOURCE flag to get many of the HP add-ons
@@ -62,10 +60,6 @@
 # reading from a NULL pointer causes a SEGV.
 ccflags="$ccflags -D_HPUX_SOURCE"
 
-# If you plan to use gcc, then you should uncomment the following line
-# so you get the HP math library and not the GCC math library.
-# ccflags="$ccflags -L/lib/pa1.1"
-
 # Check if you're using the bundled C compiler.  This compiler doesn't support
 # ANSI C (the -Aa flag) nor can it produce shared libraries.  Thus we have
 # to turn off dynamic loading.
@@ -84,16 +78,6 @@ EOM
 	esac
     else
 	ccflags="$ccflags -Aa"	# The add-on compiler supports ANSI C
-	# cppstdin and cpprun need the -Aa option if you use the unbundled 
-	# ANSI C compiler (*not* the bundled K&R compiler or gcc)
-	# [XXX this should be set automatically by Configure, but isn't yet.]
-	# [XXX This is reported not to work.  You may have to edit config.sh.
-	#  After running Configure, set cpprun and cppstdin in config.sh,
-	#  run "Configure -S" and then "make".]
-	cpprun="${cc:-cc} -E -Aa"
-	cppstdin="$cpprun"
-	cppminus='-'
-	cpplast='-'
     fi
     # For HP's ANSI C compiler, up to "+O3" is safe for everything
     # except shared libraries (PIC code).  Max safe for PIC is "+O2".
@@ -104,6 +88,12 @@ EOM
     ;;
 esac
 
+# Even if you use gcc, prefer the HP math library over the GNU one.
+
+case "`$cc -v 2>&1`" in
+"*gcc*" ) test -d /lib/pa1.1 && ccflags="$ccflags -L/lib/pa1.1" ;;
+esac
+
 # Determine the architecture type of this system.
 # Keep leading tab below -- Configure Black Magic -- RAM, 03/02/97
 	xxOsRevMajor=`uname -r | sed -e 's/^[^0-9]*//' | cut -d. -f1`;
@@ -186,4 +176,3 @@ esac
 #     assembler of the form:
 #          (warning) Use of GR3 when frame >= 8192 may cause conflict.
 #     These warnings are harmless and can be safely ignored.
-
