@@ -1,11 +1,12 @@
 # hints/netbsd.sh
 #
-# talk to packages@netbsd.org if you want to change this file.
+# talk to mrg@eterna.com.au if you want to change this file.
 #
 # netbsd keeps dynamic loading dl*() functions in /usr/lib/crt0.o,
 # so Configure doesn't find them (unless you abandon the nm scan).
 # this should be *just* 0.9 below as netbsd 0.9a was the first to
-# introduce shared libraries.
+# introduce shared libraries.  however, they don't work/build on
+# pmax, powerpc and alpha ports correctly, yet.
 
 case "$archname" in
 '')
@@ -18,26 +19,26 @@ case "$osvers" in
 	usedl="$undef"
 	;;
 *)
-	if [ -f /usr/libexec/ld.elf_so ]; then
-		d_dlopen=$define
-		d_dlerror=$define
-		ccdlflags="-Wl,-E -Wl,-R${PREFIX}/lib $ccdlflags"
-		cccdlflags="-DPIC -fPIC $cccdlflags"
-		lddlflags="--whole-archive -shared $lddlflags"
-	elif [ "`uname -m`" = "pmax" ]; then
-# NetBSD 1.3 and 1.3.1 on pmax shipped an `old' ld.so, which will not work.
+	case `uname -m` in
+	alpha|powerpc|pmax)
 		d_dlopen=$undef
-	elif [ -f /usr/libexec/ld.so ]; then
+		;;
+# this doesn't work (yet).
+#	alpha)
+#		d_dlopen=$define
+#		d_dlerror=$define
+#		cccdlflags="-DPIC -fPIC $cccdlflags"
+#		lddlflags="-shared $lddlflags"
+#		;;
+	*)
 		d_dlopen=$define
 		d_dlerror=$define
-		ccdlflags="-Wl,-R${PREFIX}/lib $ccdlflags"
 # we use -fPIC here because -fpic is *NOT* enough for some of the
 # extensions like Tk on some netbsd platforms (the sparc is one)
 		cccdlflags="-DPIC -fPIC $cccdlflags"
 		lddlflags="-Bforcearchive -Bshareable $lddlflags"
-	else
-		d_dlopen=$undef
-	fi
+		;;
+	esac
 	;;
 esac
 
@@ -46,26 +47,12 @@ esac
 # way to make perl call setuid() or setgid().  if they aren't, then
 # ($<, $>) = ($u, $u); will work (same for $(/$)).  this is because
 # you can not change the real userid of a process under 4.4BSD.
-# netbsd fixed this in 1.3.2.
+# netbsd fixed this in 1.2A.
 case "$osvers" in
-0.9*|1.[012]*|1.3|1.3.1)
+0.9*|1.0*|1.1*|1.2_*|1.2|1.2.*)
 	d_setregid="$undef"
 	d_setreuid="$undef"
+	d_setrgid="$undef"
+	d_setruid="$undef"
 	;;
 esac
-
-# These are obsolete in any netbsd.
-d_setrgid="$undef"
-d_setruid="$undef"
-
-# there's no problem with vfork.
-case "$usevfork" in
-'') usevfork=true ;;
-esac
-
-# Pre-empt the /usr/bin/perl question of installperl.
-installusrbinperl='undef'
-
-# Avoid telldir prototype conflict in pp_sys.c  (NetBSD uses const DIR *)
-# Configure should test for this.  Volunteers?
-pp_sys_cflags='ccflags="$ccflags -DHAS_TELLDIR_PROTOTYPE"'
