@@ -118,10 +118,6 @@ register struct op *op asm(stringify(OP_IN_REGISTER));
 # define DONT_DECLARE_STD 1
 #endif
 
-#if defined(NeXT) && !defined(_POSIX_SOURCE)
-#   define MISSING_PID_T
-#endif
-
 #if defined(HASVOLATILE) || defined(STANDARD_C)
 #   ifdef __cplusplus
 #	define VOL		// to temporarily suppress warnings
@@ -138,10 +134,6 @@ register struct op *op asm(stringify(OP_IN_REGISTER));
 #define TAINT_ENV()	if (tainting) { taint_env(); }
 #define TAINT_PROPER(s)	if (tainting) { taint_proper(no_security, s); }
 
-#ifdef MISSING_PID_T
-typedef int pid_t;
-#endif
-
 /* XXX All process group stuff is handled in pp_sys.c.  Should these 
    defines move there?  If so, I could simplify this a lot. --AD  9/96.
 */
@@ -1108,6 +1100,8 @@ union any {
 #include "hv.h"
 #include "mg.h"
 #include "scope.h"
+#include "bytecode.h"
+#include "byterun.h"
 
 /* work around some libPW problems */
 #ifdef DOINIT
